==> ember-0.4.0.tar.bz2: ember-0.4.0/src/components/ogre/SceneManagers/EmberPagingSceneManager/include/OgrePagingLandScapeTextureCoordinatesManager.h <==
/***************************************************************************
OgrePagingLandScapeRenderableManager.h  -  description
-------------------
begin                : Mon Jun 16 2003
copyright            : (C) 2003-2005 by Jose A Milan && Tuan Kuranes
email                : spoke2@supercable.es && tuan.kuranes@free.fr
***************************************************************************/

/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************/

#ifndef PAGINGLandScapeTextureCoordinatesMANAGER_H
#define PAGINGLandScapeTextureCoordinatesMANAGER_H

#include "OgrePagingLandScapePrerequisites.h"
#include "OgreSingleton.h"

namespace Ogre
{
	/** Class to manage the creation, destruction and use of PagingLandScapeRenderables.
	@remarks
	This class is used as a store of PagingLandScapeTexturecoordinatesBuffer shared between Page 
	*/
	class PagingLandScapeTextureCoordinatesManager : public Singleton< PagingLandScapeTextureCoordinatesManager >
	{
	public:
		/** Initializes the PagingLandScapeTextureCoordinatesManager with the 
		* given options and allocate the necessary memory.
		*/
		PagingLandScapeTextureCoordinatesManager(void);
		virtual ~PagingLandScapeTextureCoordinatesManager(void);
		static PagingLandScapeTextureCoordinatesManager& getSingleton(void);
		static PagingLandScapeTextureCoordinatesManager* getSingletonPtr(void);

		void load(void);
		void clear(void);

		HardwareVertexBufferSharedPtr getBuffer(const uint tilex, const uint tilez);

	protected:

		uint mPageSize; 
		uint mTileSize;
		
		PagingLandScapeOptions *mOption;
		HardwareTextureBuffersCol mTexBuffs; 
	};

}

#endif //PAGINGLandScapeTextureCoordinatesMANAGER_H

==> ember-0.4.1.tar.bz2: ember-0.4.1/src/components/ogre/SceneManagers/EmberPagingSceneManager/include/OgrePagingLandScapeTextureCoordinatesManager.h <==
/***************************************************************************
OgrePagingLandScapeRenderableManager.h  -  description
-------------------
begin                : Mon Jun 16 2003
copyright            : (C) 2003-2005 by Jose A Milan && Tuan Kuranes
email                : spoke2@supercable.es && tuan.kuranes@free.fr
***************************************************************************/

/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************/

#ifndef PAGINGLandScapeTextureCoordinatesMANAGER_H
#define PAGINGLandScapeTextureCoordinatesMANAGER_H

#include "OgrePagingLandScapePrerequisites.h"

namespace Ogre
{
	/** Class to manage the creation, destruction and use of PagingLandScapeRenderables.
	@remarks
	This class is used as a store of PagingLandScapeTexturecoordinatesBuffer shared between Page 
	*/
	class PagingLandScapeTextureCoordinatesManager 
	{
	public:
		/** Initializes the PagingLandScapeTextureCoordinatesManager with the 
		* given options and allocate the necessary memory.
		*/
		PagingLandScapeTextureCoordinatesManager(PagingLandScapeSceneManager * scnMgr);
		virtual ~PagingLandScapeTextureCoordinatesManager(void);
		void load(void);
		void clear(void);

		HardwareVertexBufferSharedPtr getBuffer(const uint tilex, const uint tilez);

        PagingLandScapeOptions*		getOptions(){return mOptions;}
    protected:

        PagingLandScapeOptions*		mOptions;
       
		uint mPageSize; 
		uint mTileSize;
		
		HardwareTextureBuffersCol mTexBuffs; 
	};

}

#endif //PAGINGLandScapeTextureCoordinatesMANAGER_H
